@@ -53,7 +53,7 @@ std::vector<bool> Cat::checkStopRules() {
   if (! std::isnan(checkRules.gainThreshold)){
     std::vector<bool> all_gainThreshold;
     for (auto item : questionSet.nonapplicable_rows) {
-      double gain = std::abs(SE_est - pow(expectedPV(item), 0.5));
+      double gain = std::abs(SE_est - std::pow(expectedPV(item), 0.5));
       bool item_threshold = gain < checkRules.gainThreshold ? true : false;
       all_gainThreshold.push_back(item_threshold);
     }
@@ -64,7 +64,7 @@ std::vector<bool> Cat::checkStopRules() {
   if (! std::isnan(checkRules.gainOverride)){
     std::vector<bool> all_gainOverride;
     for (auto item : questionSet.nonapplicable_rows) {
-      double gain = std::abs(SE_est - pow(expectedPV(item), 0.5));
+      double gain = std::abs(SE_est - std::pow(expectedPV(item), 0.5));
       bool item_override = gain >= checkRules.gainOverride ? true : false;
       all_gainOverride.push_back(item_override);
     }
